'\" Copyright (c) 1994 The Board of Trustees of The Leland Stanford
'\" Junior University.  All rights reserved.
'\" 
'\" Permission to use, copy, modify and distribute this software and its
'\" documentation for any purpose is hereby granted without fee, provided
'\" that the above copyright notice and this permission notice appear in
'\" all copies of this software and that you do not sell the software.
'\" Commercial licensing is available by contacting the author.
'\" 
'\" THE SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY OF ANY KIND,
'\" EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
'\" WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
'\" 
'\" Author:
'\"    Phil Lacroute
'\"    Computer Systems Laboratory
'\"    Electrical Engineering Dept.
'\"    Stanford University
'\" 
'\" $Date: 1994/12/31 19:49:53 $
'\" $Revision: 1.1 $
'\"
'\" Macros
'\" .FS <type>  --  function start
'\"     <type> is return type of function
'\"     name and arguments follow on next line
.de FS
.PD 0v
.PP
\\$1
.HP 8
..
'\" .FA  --  function arguments
'\"     one argument declaration follows on next line
.de FA
.IP " " 4
..
'\" .FE  --  function end
'\"     end of function declaration
.de FE
.PD
..
'\" .DS  --  display start
.de DS
.IP " " 4
..
'\" .DE  --  display done
.de DE
.LP
..
.TH vpSetDebug 3 "" VolPack
.SH NAME
vpSetDebug \- enable/disable debugging options
.SH SYNOPSIS
#include <volpack.h>
.sp
.FS vpResult
\fBvpSetDebug(\fIvpc, flag, value\fB)\fR
.FA
vpContext *\fIvpc;\fR
.FA
int \fIflag;\fR
.FA
int \fIvalue;\fR
.FE
.SH ARGUMENTS
.IP \fIvpc\fR
VolPack context from \fBvpCreateContext.\fR
.IP \fIflag\fR
Constant that specifies the debugging option to be adjusted.
.IP \fIvalue\fR
New value for the option (boolean: 0 or 1).
.SH DESCRIPTION
\fBvpSetDebug\fR is used to enable or disable a debugging option in a
rendering context.  The debugging options cause messages to be printed
during execution.  These messages are probably useless without a
good understanding of the source code.  If the \fIvalue\fR option
is 0 then the option is disabled; otherwise it is enabled.  The
following list summarizes all available options:
.IP VPDEBUG_VIEW
view transform calculations
.IP VPDEBUG_RENDER
high-level rendering stages
.IP VPDEBUG_RBUF
intermediate image (render buffer) allocation
.IP VPDEBUG_OPCCORRECT
opacity correction
.IP VPDEBUG_DEPTHCUE
depth cueing
.IP VPDEBUG_PYRAMID
pyramid construction
.IP VPDEBUG_OCTREE
octree construction
.IP VPDEBUG_CLSFYOCTREE
octree classification
.IP VPDEBUG_OCTREERUNS
runs computed from octree
.IP VPDEBUG_OCTREETRAVERSE
octree traversal
.IP VPDEBUG_TRANSPOSE
volume transposing
.IP VPDEBUG_COMPOSITE
compositing
.PP
The VolPack library must be compiled with the -DDEBUG compiler option
for this function to have any effect.
.SH ERRORS
The normal return value is VP_OK.  The following error return value is
possible:
.IP VPERROR_BAD_OPTION
The \fIflag\fR argument is invalid.
.SH SEE ALSO
VolPack(3), vpCreateContext(3)
